#!/bin/bash

###
#
#	脚本功能：用于读取当天深圳和上海证券交易所A股数据并存入 当日日期.csv文件
#	日期：2009-11-21
#	作者:姚汉
#	版权：BSD
#	she.list为深市股票地址列表
#	sha.list为沪市股票地址列表
#	下载文件的格式：
#	1：股票名字；
#	2：今日开盘价；
#	3：昨日收盘价；
#	4：当前价格；
#	5：今日最高价；
#	6：今日最低价；
#	7：竞买价，即“买一”报价；
#	8：竞卖价，即“卖一”报价；
#	9：成交的股票数，由于股票交易以一百股为基本单位，所以在使用时，通常把该值除以一百；
#	10：成交金额，单位为“元”，为了一目了然，通常以“万元”为成交金额的单位，所以通常把该值除以一万；
#	11：“买一”申请4695股，即47手；
#	12：“买一”报价；
#	13：“买二”
#	14：“买二”
#	15：“买三”
#	16：“买三”
#	17：“买四”
#	18：“买四”
#	19：“买五”
#	20：“买五”
#	21：“卖一”申报3100股，即31手；
#	22：，“卖一”报价
#	(23, 24), (25, 26), (27,28), (29, 30)分别为“卖二”至“卖四的情况”
#	31：日期；
#	32：时间；
#
#	结果文件0.csv每列的意义：
#	1.交易代码
#	2.日期
#	3.收盘价
#	4.成交量
#	5.最高价
#	6.最低价
#	7.开盘价
#	8.交易市场
#	9.成交金额
#
###





d=`date --rfc-3339="date"`
#建立目录并进入建立的目录
mkdir $d
cp she.list ./$d/she.list
cp sha.list ./$d/sha.list
cd $d /


##	下载深市数据
echo "下载深圳证券交易所数据..."
wget -nv -i she.list

#	合并文件

echo "合并并处理深圳证券交易所的数据..."
for i in `ls list=sz*`;do cat $i >> tmp.0 ;done

#	转换编码
enca -x utf-8 tmp.0

#	判断当天是否为交易日
#c=awk '{print $(32)}' tmp.7
#if( $c != $d ) echo "今天不是交易日";

#	格式处理、重新排序、删掉多余的数据
sed 's/\;v/\;\nv/g' tmp.0 > tmp.1
sed '/"";$/'d tmp.1 > tmp.2
sed 's/var hq_str_sz//g' tmp.2 > tmp.3
sed 's/\,/\t/g' tmp.3 > tmp.4
sed 's/=/\t/' tmp.4 > tmp.5
sed 's/"\;/\t深圳证券交易所/' tmp.5 > tmp.6
sed 's/ /_/g' tmp.6 > tmp.7
awk '{print $1 "\t" $(32) "\t" $5 "\t" $10 "\t" $6 "\t" $7 "\t" $3 "\t" $(34) "\t" $(11)}' tmp.7 > tmp.8
sed 's/_/ /g' tmp.8 > 0.csv

#	清理临时文件
rm tmp.*
rm list*

##	下载沪市数据
echo "下载上海证券交易所数据..."

wget -nv -i sha.list

#	合并文件
echo "合并并处理上海证券交易所的数据..."
for i in `ls list=sh*`;do cat $i >> tmp.0 ;done

#	转换编码
enca -x utf-8 tmp.0

#	格式处理、重新排序、删掉多余的数据
sed 's/\;v/\;\nv/g' tmp.0 > tmp.1
sed '/"";$/'d tmp.1 > tmp.2
sed 's/var hq_str_sh//g' tmp.2 > tmp.3
sed 's/\,/\t/g' tmp.3 > tmp.4
sed 's/=/\t/' tmp.4 > tmp.5
sed 's/"\;/\t上海证券交易所/' tmp.5 > tmp.6
sed 's/ /_/g' tmp.6 > tmp.7
awk '{print $1 "\t" $(32) "\t" $5 "\t" $10 "\t" $6 "\t" $7 "\t" $3 "\t" $(34) "\t" $(11)}' tmp.7 > tmp.8
sed 's/_/ /g' tmp.8 >> 0.csv

echo "生成最后结果并删除临时文件..."
#	清理临时文件
rm tmp.*
rm she.list
rm sha.list
rm list*
cp 0.csv ../$d.csv #输出
rm 0.csv
rm -rf `pwd`
cd ../
echo "文件保存到 `pwd`/$d.csv 完成！"

